@@ -153,35 +153,45 @@ class account():
         return user
         
     def setProfileInfo(self):
-        try:
-            user = self.getProfileInfo(self.accountdata.username)
-            self.controller.ui.profileTweetsLabel.set_markup("<span weight = 'bold' foreground=\"#6bd3ff\">TweetCount: </span>" +str(user.GetStatusesCount()))
-            self.controller.ui.profileFollowerCount.set_markup("<span weight = 'bold' foreground=\"#6bd3ff\">Followers: </span>"+str(user.GetFollowersCount()))
-            self.controller.ui.profileFollowingCount.set_markup("<span weight = 'bold' foreground=\"#6bd3ff\">Following: </span>" +str(user.GetFriendsCount()))
-            self.friendCount = user.GetFriendsCount()
-            self.controller.ui.accountNameLabel.set_markup(self.accountdata.username)
-            status = user.GetStatus()
-            print "formatting tweet"
-            source = self.getSourceAppname(status.GetSource())
-            formattedTweet =  self.format_tweet(user.GetName(), status.GetText(), status.GetCreatedAt(), source, status.GetInReplyToScreenName())
-            
-            self.controller.ui.profileLastTweet.set_markup("<span weight = 'bold' foreground=\"#6bd3ff\">Last Tweet: </span>" + formattedTweet)
-            
-            if (user.GetStatus().GetPlace() != None):
-                self.controller.ui.profileLocation.set_markup("<span weight = 'bold' foreground=\"#6bd3ff\">Location: </span>" +user.GetStatus().GetPlace().name)
-            else:
-                if (user.GetLocation() != None):
-                    self.controller.ui.profileLocation.set_markup("<span weight = 'bold' foreground=\"#6bd3ff\">Location: </span>" +user.GetLocation())
+        tryCount=0
+        #retry in the event of an error on the assumption it's transitory
+        while (tryCount<=5):
+            try:
+                user = self.getProfileInfo(self.accountdata.username)
+                self.controller.ui.profileTweetsLabel.set_markup("<span weight = 'bold' foreground=\"#6bd3ff\">TweetCount: </span>" +str(user.GetStatusesCount()))
+                self.controller.ui.profileFollowerCount.set_markup("<span weight = 'bold' foreground=\"#6bd3ff\">Followers: </span>"+str(user.GetFollowersCount()))
+                self.controller.ui.profileFollowingCount.set_markup("<span weight = 'bold' foreground=\"#6bd3ff\">Following: </span>" +str(user.GetFriendsCount()))
+                self.friendCount = user.GetFriendsCount()
+                self.controller.ui.accountNameLabel.set_markup(self.accountdata.username)
+                status = user.GetStatus()
+                print "formatting tweet"
+                source = self.getSourceAppname(status.GetSource())
+                formattedTweet =  self.format_tweet(user.GetName(), status.GetText(), status.GetCreatedAt(), source, status.GetInReplyToScreenName())
                 
-            avatar, loaded = self.retrieve_avatar(user.GetProfileImageUrl(), str(user.id)+".jpg")   
-            avatar = avatar.scale_simple(90, 90, gtk.gdk.INTERP_BILINEAR)
-            #self.controller.ui.profileImage.set_from_file("/home/user/.witterPics/" + self.accountdata.servicename + "/" + str(user.id)+".jpg")
-            self.controller.ui.profileImage.set_from_pixbuf(avatar)  
-            self.getSavedSearches()
-            self.getLists()
-        except AttributeError, ae:
-            print "Failed to load profile info" 
-            print ae
+                self.controller.ui.profileLastTweet.set_markup("<span weight = 'bold' foreground=\"#6bd3ff\">Last Tweet: </span>" + formattedTweet)
+                
+                if (user.GetStatus().GetPlace() != None):
+                    self.controller.ui.profileLocation.set_markup("<span weight = 'bold' foreground=\"#6bd3ff\">Location: </span>" +user.GetStatus().GetPlace().name)
+                else:
+                    if (user.GetLocation() != None):
+                        self.controller.ui.profileLocation.set_markup("<span weight = 'bold' foreground=\"#6bd3ff\">Location: </span>" +user.GetLocation())
+                    
+                avatar, loaded = self.retrieve_avatar(user.GetProfileImageUrl(), str(user.id)+".jpg")   
+                avatar = avatar.scale_simple(90, 90, gtk.gdk.INTERP_BILINEAR)
+                #self.controller.ui.profileImage.set_from_file("/home/user/.witterPics/" + self.accountdata.servicename + "/" + str(user.id)+".jpg")
+                self.controller.ui.profileImage.set_from_pixbuf(avatar)  
+                self.getSavedSearches()
+                self.getLists()
+                return
+            except AttributeError, ae:
+                tryCount=tryCount+1
+                print "Failed to load profile info" 
+                print ae
+            except IOError, e:
+                tryCount = tryCount+1
+                print "error"
+                msg = 'Error retrieving tweets '
+        print "Failed to retrieve profile info after 5 attempts"
             
     def clearSearchResults(self):
         self.searchstore.clear()
@@ -271,33 +281,140 @@ class account():
         print "base url = " + self.accountdata.baseUrl
         print "base url of api object = " + self.api.GetBaseUrl()
         receive_count = 0
-        try:
-            #by default we get newer tweets
-            if (older == False):
-                if self.accountdata.last_id == None:
-                    data = self.api.GetFriendsTimeline()
-                    rtdata = self.api.GetRetweets_to_user()
+        tryCount=0
+        while (tryCount <5):
+            try:
+                #by default we get newer tweets
+                if (older == False):
+                    if self.accountdata.last_id == None:
+                        data = self.api.GetFriendsTimeline()
+                        rtdata = self.api.GetRetweets_to_user()
+                    else:
+                        print "refreshing since" + str(self.accountdata.last_id)
+                        data = self.api.GetFriendsTimeline(since_id=self.accountdata.last_id, count=200)
+                        rtdata = self.api.GetRetweets_to_user(since_id=self.accountdata.last_id, count=200)
                 else:
-                    print "refreshing since" + str(self.accountdata.last_id)
-                    data = self.api.GetFriendsTimeline(since_id=self.accountdata.last_id, count=200)
-                    rtdata = self.api.GetRetweets_to_user(since_id=self.accountdata.last_id, count=200)
-            else:
-                if self.accountdata.oldest_id == None:
-                    data = self.api.GetFriendsTimeline(count=get_count)
-                    print "fetching retweets to user"
-                    rtdata = self.api.GetRetweets_to_user(count=get_count)
+                    if self.accountdata.oldest_id == None:
+                        data = self.api.GetFriendsTimeline(count=get_count)
+                        print "fetching retweets to user"
+                        rtdata = self.api.GetRetweets_to_user(count=get_count)
+                    else:
+                        print "refreshing retweets prior to" + str(self.accountdata.oldest_id)
+                        data = self.api.GetFriendsTimeline(max_id=self.accountdata.oldest_id, count=get_count)
+                        rtdata = self.api.GetRetweets_to_user(max_id=self.accountdata.oldest_id, count=get_count)
+                data += rtdata
+                for x in data:
+                     if x != None:
+                         if (self.checkStoreForTweet(long(x.id),self.tweetstore)):
+                             print "Tweet already in store"
+                         else:
+                             if (self.accountdata.last_id != None):
+                                if (x.id == self.accountdata.last_id):
+                                    continue
+                             if (None != x.in_reply_to_status_id):
+                                print "reply to " + x.in_reply_to_screen_name
+                                #we don't want anything showing up if there is no reply_to, so all teh formatting is held here including the newline
+                                reply_to = "In reply to: " + x.in_reply_to_screen_name + " - " + self.get_specific_tweet(x.in_reply_to_screen_name, x.in_reply_to_status_id)
+                             else:
+                                reply_to = ""
+        
+                             reply_to = reply_to.replace("&", "&amp;")
+                             #need to store id numbers for oldest/newest
+                             if self.accountdata.last_id == None:
+                                self.accountdata.last_id = x.id
+                             else:
+                                #if we have an id stored, check if this one is 'newer' if so then store it
+                                if long(self.accountdata.last_id) < long(x.id):
+                                    self.accountdata.last_id = x.id
+        
+                             #also want to track the oldest we get hold of
+                             if self.accountdata.oldest_id == None:
+                                self.accountdata.oldest_id = x.id
+                             else:
+                                if long(self.accountdata.oldest_id) > long(x.id):
+                                    self.accountdata.oldest_id = x.id
+                             #strip the source app name from the url
+                             source = self.getSourceAppname(x.source)
+                             text = self.escapeText(x.text)
+                             text = self.controller.expandBitlyUrls(text)
+                             if (x.GetPlace() !=None):
+                                 place = x.GetPlace().name
+                             else:
+                                 place=None
+                             
+                             pic = self.set_pic_for_id(str(x.user.GetId()), x.user.GetScreenName(), x.user.GetProfileImageUrl())
+                             created_at = self.parse_time(x.created_at)
+                             formatted_ts = self.format_timestamp(created_at)
+                             formatted_tweet = self.format_tweet(x.user.screen_name, text, formatted_ts, source, reply_to, loc=place)
+                             longid= long(x.id)
+                             self.tweetstore.append([ "@" + x.user.screen_name, str(x.user.GetId()), "@" + x.user.screen_name + " : " + text, "", longid, "Tweet", x.created_at, reply_to, source, pic, formatted_tweet, True])
+                             
+                             receive_count = receive_count + 1
+    
+                if (receive_count > 0):
+                    note = osso.SystemNote(self.osso_c)
+                    result = note.system_note_infoprint(str(receive_count) + " Tweets Received")
+                return    
+            except IOError, e:
+                tryCount = tryCount+1
+                print "error"
+                msg = 'Error retrieving tweets '
+                if hasattr(e, 'reason'):
+                    msg = msg + str(e.reason)
+    
+                if hasattr(e, 'code'):
+                    if (e.code == 401):
+                        reason = "Not authorised: check uid/pwd"
+                    elif(e.code == 503):
+                        reason = "Service unavailable"
+                    else:
+                        reason = ""
+                    msg = msg + 'Server returned ' + str(e.code) + " : " + reason
+                print "get Tweets try : " + str(tryCount)+": " +msg
+                print "sleep for 1 second, then try again"
+                time.sleep(1)
+            except httplib.BadStatusLine:
+                tryCount = tryCount+1
+                msg ="Bad Status Line"
+                print "Network error - BadStatusLine"
+                print "sleep for 1 second, then try again"
+                time.sleep(1)
+        print "Failed to retrieve tweets after 5 attempts"
+        if (auto == 0):
+            note = osso.SystemNote(self.osso_c)
+            note.system_note_dialog(msg)
+        
+        
+
+    def getMentions(self, auto=0, older=False, get_count=20, * args):
+        if (self.api == None):
+            if (self.connect() != True):
+                return
+        print "getting mentions"
+        receive_count = 0
+        tryCount=0
+        while (tryCount <5):
+            try:
+                #by default we get newer tweets
+                if (older == False):
+                    if self.accountdata.last_mention_id == None:
+                        data = self.api.GetReplies()
+                    else:
+                        print "refreshing since" + str(self.accountdata.last_mention_id)
+                        data = self.api.GetReplies(since_id=self.accountdata.last_mention_id)
                 else:
-                    print "refreshing retweets prior to" + str(self.accountdata.oldest_id)
-                    data = self.api.GetFriendsTimeline(max_id=self.accountdata.oldest_id, count=get_count)
-                    rtdata = self.api.GetRetweets_to_user(max_id=self.accountdata.oldest_id, count=get_count)
-            data += rtdata
-            for x in data:
-                 if x != None:
-                     if (self.checkStoreForTweet(long(x.id),self.tweetstore)):
+                    if self.accountdata.oldest_mention_id == None:
+                        data = self.api.GetReplies(count=get_count)
+                    else:
+                        print "refreshing prior to" + str(self.accountdata.oldest_mention_id)
+                        data = self.api.GetReplies(max_id=self.accountdata.oldest_mention_id, count=get_count)
+    
+                for x in data:
+                     if (self.checkStoreForTweet(long(x.id),self.mentionstore)):
                          print "Tweet already in store"
                      else:
-                         if (self.accountdata.last_id != None):
-                            if (x.id == self.accountdata.last_id):
+                         if (self.accountdata.last_mention_id != None):
+                            if (x.id == self.accountdata.last_mention_id):
                                 continue
                          if (None != x.in_reply_to_status_id):
                             print "reply to " + x.in_reply_to_screen_name
@@ -308,167 +425,77 @@ class account():
     
                          reply_to = reply_to.replace("&", "&amp;")
                          #need to store id numbers for oldest/newest
-                         if self.accountdata.last_id == None:
-                            self.accountdata.last_id = x.id
+                         if self.accountdata.last_mention_id == None:
+                            self.accountdata.last_mention_id = x.id
                          else:
                             #if we have an id stored, check if this one is 'newer' if so then store it
-                            if long(self.accountdata.last_id) < long(x.id):
-                                self.accountdata.last_id = x.id
+                            if long(self.accountdata.last_mention_id) < long(x.id):
+                                self.accountdata.last_mention_id = x.id
     
                          #also want to track the oldest we get hold of
-                         if self.accountdata.oldest_id == None:
-                            self.accountdata.oldest_id = x.id
+                         if self.accountdata.oldest_mention_id == None:
+                            self.accountdata.oldest_mention_id = x.id
                          else:
-                            if long(self.accountdata.oldest_id) > long(x.id):
-                                self.accountdata.oldest_id = x.id
+                            if long(self.accountdata.oldest_mention_id) > long(x.id):
+                                self.accountdata.oldest_mention_id = x.id
                          #strip the source app name from the url
                          source = self.getSourceAppname(x.source)
                          text = self.escapeText(x.text)
                          text = self.controller.expandBitlyUrls(text)
-                         if (x.GetPlace() !=None):
-                             place = x.GetPlace().name
-                         else:
-                             place=None
-                         
                          pic = self.set_pic_for_id(str(x.user.GetId()), x.user.GetScreenName(), x.user.GetProfileImageUrl())
                          created_at = self.parse_time(x.created_at)
                          formatted_ts = self.format_timestamp(created_at)
-                         formatted_tweet = self.format_tweet(x.user.screen_name, text, formatted_ts, source, reply_to, loc=place)
-                         longid= long(x.id)
-                         self.tweetstore.append([ "@" + x.user.screen_name, str(x.user.GetId()), "@" + x.user.screen_name + " : " + text, "", longid, "Tweet", x.created_at, reply_to, source, pic, formatted_tweet, True])
-                         
+                         formatted_tweet = self.format_tweet(x.user.screen_name, text, formatted_ts, source, reply_to)
+                         self.mentionstore.append([ "@" + x.user.screen_name, str(x.user.GetId()), "@" + x.user.screen_name + " : " + text, "", long(x.id), "Tweet", x.created_at, reply_to, source, pic, formatted_tweet, True])
                          receive_count = receive_count + 1
-
-            if (receive_count > 0):
-                note = osso.SystemNote(self.osso_c)
-                result = note.system_note_infoprint(str(receive_count) + " Tweets Received")
-                
-        except IOError, e:
-            print "error"
-            msg = 'Error retrieving tweets '
-            if hasattr(e, 'reason'):
-                msg = msg + str(e.reason)
-
-            if hasattr(e, 'code'):
-                if (e.code == 401):
-                    reason = "Not authorised: check uid/pwd"
-                elif(e.code == 503):
-                    reason = "Service unavailable"
-                else:
-                    reason = ""
-                msg = msg + 'Server returned ' + str(e.code) + " : " + reason
-            if (auto == 0):
-                note = osso.SystemNote(self.osso_c)
-                note.system_note_dialog(msg)
-            print msg
-        except httplib.BadStatusLine:
-            print "Network error - BadStatusLine"
-            if (auto == 0):
-                note = osso.SystemNote(self.osso_c)
-                note.system_note_dialog("Network error occured. Please try again")
-        
-
-    def getMentions(self, auto=0, older=False, get_count=20, * args):
-        if (self.api == None):
-            if (self.connect() != True):
+    
+                if (receive_count > 0):
+                    if (self.controller.emailnotifications == False):
+                        note = osso.SystemNote(self.osso_c)
+                        result = note.system_note_infoprint(str(receive_count) + " Mentions Received")
+                    else:
+                        n = pynotify.Notification("Witter","You have "+str(receive_count)+" new mentions")
+                        n.set_urgency(pynotify.URGENCY_CRITICAL)
+                        icon= gtk.gdk.pixbuf_new_from_file("/opt/witter/icons/default/tweet.png")
+                        #n.add_action("clicked","Show DMs", self.dm_callback)
+                        n.set_hint("dbus-callback-default", "uk.wouldd.witter /uk/wouldd/witter uk.wouldd.witter open_mentions")
+                        n.set_icon_from_pixbuf(icon)
+                        rpc = osso.Rpc(self.osso_c)
+                        rpc.rpc_run(self._MCE_SERVICE, self._MCE_REQUEST_PATH,self._MCE_REQUEST_IF,self._ENABLE_LED,rpc_args=(self._LED_PATTERN,"",""),use_system_bus=True)
+                        rpc.rpc_run(self._MCE_SERVICE, self._MCE_REQUEST_PATH,self._MCE_REQUEST_IF,self._VIBRATE,rpc_args=(self._VIBRATE_PATTERN,"",""),use_system_bus=True)
+                        #n.attach_to_widget(self.controller.ui.window)
+                        n.show()
                 return
-        print "getting mentions"
-        receive_count = 0
-        try:
-            #by default we get newer tweets
-            if (older == False):
-                if self.accountdata.last_mention_id == None:
-                    data = self.api.GetReplies()
-                else:
-                    print "refreshing since" + str(self.accountdata.last_mention_id)
-                    data = self.api.GetReplies(since_id=self.accountdata.last_mention_id)
-            else:
-                if self.accountdata.oldest_mention_id == None:
-                    data = self.api.GetReplies(count=get_count)
-                else:
-                    print "refreshing prior to" + str(self.accountdata.oldest_mention_id)
-                    data = self.api.GetReplies(max_id=self.accountdata.oldest_mention_id, count=get_count)
-
-            for x in data:
-                 if (self.checkStoreForTweet(long(x.id),self.mentionstore)):
-                     print "Tweet already in store"
-                 else:
-                     if (self.accountdata.last_mention_id != None):
-                        if (x.id == self.accountdata.last_mention_id):
-                            continue
-                     if (None != x.in_reply_to_status_id):
-                        print "reply to " + x.in_reply_to_screen_name
-                        #we don't want anything showing up if there is no reply_to, so all teh formatting is held here including the newline
-                        reply_to = "In reply to: " + x.in_reply_to_screen_name + " - " + self.get_specific_tweet(x.in_reply_to_screen_name, x.in_reply_to_status_id)
-                     else:
-                        reply_to = ""
-
-                     reply_to = reply_to.replace("&", "&amp;")
-                     #need to store id numbers for oldest/newest
-                     if self.accountdata.last_mention_id == None:
-                        self.accountdata.last_mention_id = x.id
-                     else:
-                        #if we have an id stored, check if this one is 'newer' if so then store it
-                        if long(self.accountdata.last_mention_id) < long(x.id):
-                            self.accountdata.last_mention_id = x.id
-
-                     #also want to track the oldest we get hold of
-                     if self.accountdata.oldest_mention_id == None:
-                        self.accountdata.oldest_mention_id = x.id
-                     else:
-                        if long(self.accountdata.oldest_mention_id) > long(x.id):
-                            self.accountdata.oldest_mention_id = x.id
-                     #strip the source app name from the url
-                     source = self.getSourceAppname(x.source)
-                     text = self.escapeText(x.text)
-                     text = self.controller.expandBitlyUrls(text)
-                     pic = self.set_pic_for_id(str(x.user.GetId()), x.user.GetScreenName(), x.user.GetProfileImageUrl())
-                     created_at = self.parse_time(x.created_at)
-                     formatted_ts = self.format_timestamp(created_at)
-                     formatted_tweet = self.format_tweet(x.user.screen_name, text, formatted_ts, source, reply_to)
-                     self.mentionstore.append([ "@" + x.user.screen_name, str(x.user.GetId()), "@" + x.user.screen_name + " : " + text, "", long(x.id), "Tweet", x.created_at, reply_to, source, pic, formatted_tweet, True])
-                     receive_count = receive_count + 1
-
-            if (receive_count > 0):
-                if (self.controller.emailnotifications == False):
+            except IOError, e:
+                tryCount=tryCount+1
+                print "error"
+                msg = 'Error retrieving mentions '
+                if hasattr(e, 'reason'):
+                    msg = msg + str(e.reason)
+    
+                if hasattr(e, 'code'):
+                    if (e.code == 401):
+                        reason = "Not authorised: check uid/pwd"
+                    elif(e.code == 503):
+                        reason = "Service unavailable"
+                    else:
+                        reason = ""
+                    msg = msg + 'Server returned ' + str(e.code) + " : " + reason
+                if (auto == 0):
                     note = osso.SystemNote(self.osso_c)
-                    result = note.system_note_infoprint(str(receive_count) + " Mentions Received")
-                else:
-                    n = pynotify.Notification("Witter","You have "+str(receive_count)+" new mentions")
-                    n.set_urgency(pynotify.URGENCY_CRITICAL)
-                    icon= gtk.gdk.pixbuf_new_from_file("/opt/witter/icons/default/tweet.png")
-                    #n.add_action("clicked","Show DMs", self.dm_callback)
-                    n.set_hint("dbus-callback-default", "uk.wouldd.witter /uk/wouldd/witter uk.wouldd.witter open_mentions")
-                    n.set_icon_from_pixbuf(icon)
-                    rpc = osso.Rpc(self.osso_c)
-                    rpc.rpc_run(self._MCE_SERVICE, self._MCE_REQUEST_PATH,self._MCE_REQUEST_IF,self._ENABLE_LED,rpc_args=(self._LED_PATTERN,"",""),use_system_bus=True)
-                    rpc.rpc_run(self._MCE_SERVICE, self._MCE_REQUEST_PATH,self._MCE_REQUEST_IF,self._VIBRATE,rpc_args=(self._VIBRATE_PATTERN,"",""),use_system_bus=True)
-                    #n.attach_to_widget(self.controller.ui.window)
-                    n.show()
+                    note.system_note_dialog(msg)
+                print msg
+            except httplib.BadStatusLine:
+                tryCount=tryCount+1
+                msg ="Bad Status Line"
+                print "Network error - BadStatusLine"
+                print "sleep for 1 second, then try again"
+                time.sleep(1)
+                
+        if (auto == 0):
+          note = osso.SystemNote(self.osso_c)
+          note.system_note_dialog(msg)
 
-        except IOError, e:
-            print "error"
-            msg = 'Error retrieving mentions '
-            if hasattr(e, 'reason'):
-                msg = msg + str(e.reason)
-
-            if hasattr(e, 'code'):
-                if (e.code == 401):
-                    reason = "Not authorised: check uid/pwd"
-                elif(e.code == 503):
-                    reason = "Service unavailable"
-                else:
-                    reason = ""
-                msg = msg + 'Server returned ' + str(e.code) + " : " + reason
-            if (auto == 0):
-                note = osso.SystemNote(self.osso_c)
-                note.system_note_dialog(msg)
-            print msg
-        except httplib.BadStatusLine:
-            print "Network error - BadStatusLine"
-            if (auto == 0):
-                note = osso.SystemNote(self.osso_c)
-                note.system_note_dialog("Network error occured. Please try again")
                  
     def getDMs(self, auto=0, older=False, get_count=20, * args):
         if (self.api == None):
