@@ -77,7 +77,7 @@ class Witter():
     #first an init method to set everything up    
     def __init__(self):
         #version of witter
-        self.version = "0.3.6"
+        self.version = "0.3.7"
         #object holding witter config
         self.config = None
         #defaults for auto-refresh
@@ -897,7 +897,7 @@ class Witter():
 
 
     def end_refresh_threads(self):
-	    self.activeAccount.stopLocation()
+	    self.activeAccount.stop_Location()
         #end all the refresh threads
 	    if (self.refreshtask != None):
 		self.refreshtask.stop()
@@ -928,9 +928,20 @@ class Witter():
         if (self.searchRefreshInterval != 0) :
 		    self.searchrefresh = witter.RefreshTask(self.getSearchWrapper, 0, None)
 		    self.searchrefresh.start(self.searchRefreshInterval * 60, self)
-            
         self.locationUpdateThread = witter.RefreshTask(self.startLocation, 0, None)
         self.locationUpdateThread.refresh()
+        
+        if (self.location):    
+            print "location sharing enabled"
+            
+            self.activeAccount.start_Location()
+        else:
+            print "location sharing disabled"
+            while (self.activeAccount.locationSetup == False):
+                print "waiting for gps thread"
+                time.sleep(2)
+            self.activeAccount.stop_Location()
+            
         print "end refresh setup"
 
     def startLocation(self, get_older=False, more=0, autoval=None):
